@@ -3,8 +3,10 @@ package Dependencies::Searcher;
 use 5.010;
 use Data::Printer;
 use feature qw(say);
-# Since 2.99 a is_core() method is available :)
-use Module::CoreList 2.99;
+# Be careful, even if the Module::Corelist module is available since v5.8.9
+# the is_core() method is only available since 2.99 module's version :)
+# http://neilb.org/2013/09/21/adding-is-core.html
+use Module::CoreList;
 use Module::Version 'get_version';
 use autodie;
 use Moose;
@@ -19,7 +21,7 @@ use Term::ANSIColor;
 # For test only during dev
 #use Dependencies::Searcher;
 
-our $VERSION = '0.066_003';
+our $VERSION = '0.066_004';
 
 =head1 NAME
 
@@ -77,7 +79,7 @@ manage dependencies between your development environment and
 production, but how to keep track of the list of modules you will pass
 to L<Carton|Carton>?
 
-Event if it is a no brainer to keep track of this list by adding it by
+Even if it is a no brainer to keep track of this list by adding it by
 hand, it can be much better not to have to do it.
 
 You will need a tool that will check for any I<requires> or I<use> in
@@ -154,6 +156,7 @@ sub get_modules {
 	if ($moduls[0] =~ m/^use/ or $moduls[0] =~ m/^require/) {
 	    return @moduls;
 	} else {
+            # Not really useful since we don't use ack no more
 	    die "Failed to retrieve modules with Ack";
 	}
     } else {
@@ -192,7 +195,7 @@ sub get_files {
 }
 
 # Generate a "1" when merging if one of both is empty
-# Will be clean in make_it_real method
+# Will be clean in avoid_superfluous() method
 sub merge_dependencies {
     my ($self, @uses, @requires) = @_;
     my @merged_dependencies = (@uses, @requires);
@@ -201,22 +204,29 @@ sub merge_dependencies {
 }
 
 # Remove special cases that aren't need at all
-sub make_it_real {
+sub avoid_superfluous {
     my ($self, @merged) = @_;
     my @real_modules;
+    # Push everything except the special cases that are totally useless
     foreach my $module ( @merged ) {
 	push(@real_modules, $module) unless
 
 	$module =~ m/say/
 
 	# Describes a minimal Perl version
+        # BUG  #76, see above
 	or $module =~ m/^use\s[0-9]\.[0-9]+?/
 	or $module =~ m/^use\sautodie?/
 	or $module =~ m/^use\swarnings/
 	# Kind of bug generated by merge_dependencies() when there is
 	# only one array to merge
 	or $module =~ m/^1$/
-	or $module =~ m/^use\sDependencies::Searcher/;
+	or $module =~ m/^use\sDependencies::Searcher/
+        # Bug #76, a regex in this module created a match ("\s" module) in the
+        # patterns search
+        # https://git.framasoft.org/smonff/dependencies-searcher/issues/76
+        or $module =~ m/\/\^use\\s/
+        or $module =~m/^use\s\\s/;
     }
     return @real_modules;
 }
@@ -338,6 +348,7 @@ sub clean_everything {
 		}
 		    {}xi;
 
+
 	say("Clean module : " . $module);
 	push @clean_modules, $module;
     }
@@ -362,9 +373,6 @@ sub dissociate {
 
     foreach my $nc_module (@common_modules) {
 
-	# The old way before 2.99 corelist
-	# my $core_list_answer = `corelist $nc_module`;
-
 	my $core_list_answer = Module::CoreList::is_core($nc_module);
 
 	if (
@@ -373,7 +381,7 @@ sub dissociate {
 	    or
 	    # In case module don't have a version number
 	    ($core_list_answer == 1)
-	) {
+           ) {
 
 	    # A module can be in core but the wanted version can be
 	    # more fresh than the core one...
@@ -414,11 +422,6 @@ sub dissociate {
 
 	    # Add to core_module
 
-	    # The old way
-	    # You have to push to an array ref (Moose)
-	    # http://www.perlmonks.org/?node_id=695034
-	    # push @{ $self->core_modules }, $nc_module;
-
 	    # The "Moose" trait way
 	    # http://metacpan.org/module/Moose::Meta::Attribute::Native::Trait::Array
 	    $self->add_core_module($nc_module);
@@ -427,7 +430,6 @@ sub dissociate {
 	} else {
 	    $self->add_non_core_module($nc_module);
 	    say($nc_module . " is not in core");
-	    # push @{ $self->non_core_modules }, $nc_module;
 	}
     }
 }
@@ -471,18 +473,6 @@ sub generate_report {
     say("File has been generated and is waiting for you");
 }
 
-# DEPRECATED
-# sub build_cmd {
-
-#     my ($self, @params) = @_;
-
-#     my @cmd = ($self->full_path, @params);
-#     my $cmd_href = \@cmd;
-
-#     return $cmd_href;
-# }
-
-
 
 # under rewriting since we removed Dependencies::Searcher::AckRequester
 sub search {
@@ -508,8 +498,13 @@ sub search {
         }
 
         my @lines = $file->slurp;
+
         for my $line (@lines) {
 
+            # if ( $line =~ /use\\s/m ) {
+            #     say "$line !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!";
+            #}
+
             # Remove carriage return
             chomp  $line;
             # Remove tabs
@@ -623,9 +618,9 @@ directories) where you want to search (array of strings from C<get_files()>).
 
 These patterns should be C<^use> or C<^require>.
 
-Then, Ack will be used to retrieve modules names into lines containing
-patterns and return them into an array (containing also some dirt).
-See L<Dependencies::Searcher::AckRequester> for more informations.
+Then, the search() subroutine will be used to retrieve modules names
+into lines containing patterns and return them into an array
+(containing also some dirt).
 
 =cut
 
@@ -637,11 +632,11 @@ CAVEATS.
 
 =cut
 
-=head2 make_it_real(@modules)
+=head2 avoid_superfluous(@modules)
 
 Move dependencies lines from an array to an another unless it is
-considered as a special case : minimal Perl versions, C<use autodie>,
-C<use warnings>. These stuff has to be B<removed>. Return a I<real
+considered as a "superfluous" unneccessary case : minimal Perl versions, C<use autodie>,
+C<use warnings>. These stuff has to be B<removed>, not cleaned. Return a I<real
 modules> array (I<real interresting> modules).
 
 =cut
